function [figures, kf_data] = diff_drive_charts_estimate_lm(true_data,kf_data)

	% display charts for diff_drive estimates

    
    
	% make figure for estimate charts
	figures.main = figure;
	
    fig_width = 2;
    fig_height = 1;
    
	% display estimated path with true measurements
	figures.estim_traj = subplot(fig_width,fig_height,1);
	plot(kf_data.x_post(:,2),kf_data.x_post(:,3),'-x');
	xlabel 'x (cm)';
	ylabel 'y (cm)';
	title 'estimated path';
	
	hold on;
	
	% add true measurements
    % nb: measurements are relative to the robots position
    % so, we add the estimate position of the robot, to get
    % the total estimated location of where the robot expects
    % the landmark to be..
    
    % convert relative lm measurements to absolute coordinates
    test = diff_drive_convert_rel_meas_to_abs(kf_data.x_prior, kf_data.z_hat);
    plot(test(:,2),test(:,3),'ro');
    
	%plot(true_data.meas(:,2)+true_data.process(:,2),true_data.meas(:,3)+true_data.process(:,3),'bo');
	test2 = diff_drive_convert_rel_meas_to_abs(true_data.process, true_data.meas);
    plot(test2(:,2),test2(:,3),'bx');
   
    plot(true_data.process(:,2),true_data.process(:,3),':');
	
    % display Guassian window
	figures.fig_uncert_x_y_gauss = subplot(fig_width,fig_height,2);
	xlabel 'x (cm)';
	ylabel 'y (cm)';
	title 'conditional probability distribution';
	
	
	% add estimates measurements
	%plot(ekf.
	
	
    
    
    
    % figure with uncertainties
    
    figures.uncertainties = figure;
    
    fig_width = 3;
    fig_height = 3;
    
    
	% display uncertainty in x estimate
	% uncertainty in x
	figures.fig_uncert_x = subplot(fig_height,fig_width,1);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,2))
	xlabel 'step';
	ylabel 'variance (cm^2)';
	title 'variance in x estimate';
	
	% uncertainty in xy
	figures.fig_uncert_xy = subplot(fig_height,fig_width,2);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,3))
	xlabel 'step';
	ylabel 'variance (cm^2)';
	title 'covariance in xy estimate';
    
    % uncertainty in xphi
	figures.fig_uncert_xphi = subplot(fig_height,fig_width,3);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,4))
	xlabel 'step';
	ylabel 'variance (cm^2)';
	title 'covariance in xphi estimate';
    
 	
	
	% display uncertainty in y estimate
	% uncertainty in y
	figures.fig_uncert_yx = subplot(fig_height,fig_width,fig_width+1);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,5));
	xlabel 'step';
	ylabel 'variance (cm^2)';
	title 'covariance in yx estimate';
	
	figures.fig_uncert_y = subplot(fig_height,fig_width,fig_width+2);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,6));
	xlabel 'step';
	ylabel 'variance (cm^2)';
	title 'variance in y estimate';
	
    figures.fig_uncert_yphi = subplot(fig_height,fig_width,fig_width+3);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,7));
	xlabel 'step';
	ylabel 'variance (cm^2)';
	title 'covariance in yphi estimate';
	
	% add meas uncertainty in y
	%hold
	%plot(data.process(:,1), problem.env.meas.noise.uncert(2,2),':');
	
	
	% display uncertainty in orientation estimate
	% uncertainty in phi
	figures.fig_uncert_phix = subplot(fig_height,fig_width,2*fig_width+1);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,8));
	xlabel 'step';
	ylabel 'variance (rad^2)';
	title 'covariance in orientation-x estimate';
	
	figures.fig_uncert_phiy = subplot(fig_height,fig_width,2*fig_width+2);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,9));
	xlabel 'step';
	ylabel 'variance (rad^2)';
	title 'covariance in orientation-y estimate';
	
    figures.fig_uncert_phi = subplot(fig_height,fig_width,2*fig_width+3);
	plot(kf_data.c_x_post(:,1),kf_data.c_x_post(:,10));
	xlabel 'step';
	ylabel 'variance (rad^2)';
	title 'variance in orientation estimate';
	
	% add meas uncertainty in phi
	%hold
	%plot(data.process(:,1),problem.env.meas.noise.uncert(3,3),':');
	
    
    figures.kgs = figure;
    
	fig_width = 3;
    fig_height = 3;
    
    % display Kalman Gains
    % convert gainmatrices to arrays
    [r c] = size(kf_data.K(1).matrix);
    [kf_data.Ks] = struct2arr(kf_data.K);
     
    % KG for x
    figures.fig_kg = subplot(fig_height,fig_width,1);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 1,1);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');
	
    
    % KG for xy
    figures.fig_kg_xy = subplot(fig_height,fig_width,2);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 1,2);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');

    % KG for xphi
    figures.fig_kg_xphi = subplot(fig_height,fig_width,3);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 1,3);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');

    
    
    % KG for yx
    figures.fig_kg_yx = subplot(fig_height,fig_width,fig_width+1);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 2,1);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');

    % KG for yy
    figures.fig_kg_yy = subplot(fig_height,fig_width,fig_width+2);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 2,2);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');

    
    % KG for yphi
    figures.fig_kg_yphi = subplot(fig_height,fig_width,fig_width+3);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 2,3);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');
   
    
    
    % KG for phix
    figures.fig_kg_phix = subplot(fig_height,fig_width,2*fig_width+1);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 3,1);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');

    
    % KG for phiy
    figures.fig_kg_phiy = subplot(fig_height,fig_width,2*fig_width+2);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 3,2);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');

    
    % KG for phiphi
    figures.fig_kg_phiphi = subplot(fig_height,fig_width,2*fig_width+3);
    
    Ks_tmp = arr2elem(kf_data.Ks, c, 3,3);
    plot(Ks_tmp(:,1), Ks_tmp(:,2),'bx');
   