function [figures] = charts_combi(true_data, kf_data, first)

	% display charts for estimates
    if nargin < 3,
        disp 'plots mixed true_data-kf_data plots';
        disp 'syntax: figures = charts_combi(true_data, kf_data, nr_of_steps_to_show)';
        error('not enough parameters');
    end;
    
%    figures = figs;
    
    % prior state trajectories
    figures.est_prior_state_trajectories = figure;
            
    [prior_val prior_uncert] = convert_step_data_2_arr(kf_data.x_prior);
    arr_source = prior_val;
    
    arr_source2 = true_data.process;
    
    
    [to c] = size(arr_source);
    state_size = c-1;
    real_state_size = state_size; %for later use in uncertainties..
    
    
    if ~(first==0),
        to = first;
    end;
    
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
    
	    % display data of element i
	    figures.est_prior_state_trajectory(i) = subplot(fig_height,fig_width,i);
        
	    plot(arr_source(1:to,1),arr_source(1:to,i+1));
    	xlabel 'step';
    	ylabel 'value';
     	title (['estimated prior and true state trajectory element ',num2str(i)]);
	
        hold on;
        plot(arr_source2(1:to,1),arr_source2(1:to,i+1),':');
        hold off;
    end
    
	    
    % diff true and estimated prior state trajectories
    figures.est_prior_state_trajectories = figure;
            
    [prior_val prior_uncert] = convert_step_data_2_arr(kf_data.x_prior);
    arr_source = prior_val;
    
    arr_source2 = true_data.process;
    
    arr_source = arr_source2 - arr_source;
        
    [r c] = size(arr_source);
    state_size = c-1;
    real_state_size = state_size; %for later use in uncertainties..
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
    
	    % display data of element i
	    figures.est_prior_state_trajectory(i) = subplot(fig_height,fig_width,i);
        
	    plot(arr_source2(1:to,1),arr_source(1:to,i+1));
    	xlabel 'step';
    	ylabel 'value';
     	title (['diff true and estimated prior state trajectory element ',num2str(i)]);

    end
    
    
    % diff true and estimated prior state trajectories with sigma intervals
    figures.est_prior_state_trajectories_with_sigma = figure;
            
    [prior_val prior_uncert] = convert_step_data_2_arr(kf_data.x_prior);
    arr_source = prior_val;
    
    arr_source2 = true_data.process;
    
    arr_source = arr_source2 - arr_source;
    
        
    [r c] = size(arr_source);
    state_size = c-1;
    real_state_size = state_size; %for later use in uncertainties..
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
    
	    % display data of element i
	    figures.est_prior_state_trajectory(i) = subplot(fig_height,fig_width,i);
        
	    plot(arr_source2(1:to,1),arr_source(1:to,i+1));
        hold on;  
        plot(prior_uncert(1:to,1),sqrt(prior_uncert(1:to,i+1+(i-1)*state_size)),'b-');
        plot(prior_uncert(1:to,1),-sqrt(prior_uncert(1:to,i+1+(i-1)*state_size)),'b-');
      	plot(prior_uncert(1:to,1),2*sqrt(prior_uncert(1:to,i+1+(i-1)*state_size)),'b-');
        plot(prior_uncert(1:to,1),-2*sqrt(prior_uncert(1:to,i+1+(i-1)*state_size)),'b-');
        xlabel 'step';
    	ylabel 'value';
     	title (['diff true and estimated prior state trajectory with sigma intervals element ',num2str(i)]);

    end
    
    
    
    
    
    % posterior state trajectories
    figures.est_post_state_trajectories = figure;
            
    [post_val post_uncert] = convert_step_data_2_arr(kf_data.x_post);
    arr_source = post_val;
    
    arr_source2 = true_data.process;
    
    [r c] = size(arr_source);
    state_size = c-1;
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
    
	    % display data of element i
	    figures.est_post_state_trajectory(i) = subplot(fig_height,fig_width,i);
        
	    plot(arr_source(1:to,1),arr_source(1:to,i+1))
    	xlabel 'step';
    	ylabel 'value';
    	title (['estimated post and true state trajectory element ',num2str(i)]);
	 
        hold on;
        plot(arr_source2(1:to,1),arr_source2(1:to,i+1),':');
        hold off;
    end
    
    % prior state trajectories
    figures.est_prior_state_trajectories = figure;
            
    [post_val prior_uncert] = convert_step_data_2_arr(kf_data.x_post);
    arr_source = post_val;
    
    arr_source2 = true_data.process;
    
    arr_source = arr_source2 - arr_source;
        
    [r c] = size(arr_source);
    state_size = c-1;
    real_state_size = state_size; %for later use in uncertainties..
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
    
	    % display data of element i
	    figures.est_prior_state_trajectory(i) = subplot(fig_height,fig_width,i);
        
	    plot(arr_source2(1:to,1),arr_source(1:to,i+1));
    	xlabel 'step';
    	ylabel 'value';
     	title (['diff true and estimated post state trajectory element ',num2str(i)]);

    end
    
    % diff true and estimated post state trajectories with sigma intervals
    figures.est_post_state_trajectories_with_sigma = figure;
            
    [post_val post_uncert] = convert_step_data_2_arr(kf_data.x_post);
    arr_source = post_val;
    
    arr_source2 = true_data.process;
    
    arr_source = arr_source2 - arr_source;
    
        
    [r c] = size(arr_source);
    state_size = c-1;
    real_state_size = state_size; %for later use in uncertainties..
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
    
	    % display data of element i
	    figures.est_poster_state_trajectory(i) = subplot(fig_height,fig_width,i);
        
	    plot(arr_source2(1:to,1),arr_source(1:to,i+1));
        hold on;  
        plot(post_uncert(1:to,1),sqrt(post_uncert(1:to,i+1+(i-1)*state_size)),'b-');
        plot(post_uncert(1:to,1),-sqrt(post_uncert(1:to,i+1+(i-1)*state_size)),'b-');
      	plot(post_uncert(1:to,1),2*sqrt(post_uncert(1:to,i+1+(i-1)*state_size)),'b-');
        plot(post_uncert(1:to,1),-2*sqrt(post_uncert(1:to,i+1+(i-1)*state_size)),'b-');
      	xlabel 'step';
    	ylabel 'value';
     	title (['diff true and estimated post state trajectory with sigma intervals element ',num2str(i)]);

    end
    
    % measurement estimate trajectories
    figures.est_meas_trajectories = figure;
            
    [z_hat_val z_hat_uncert] = convert_step_data_2_arr(kf_data.z_hat);
    arr_source = z_hat_val;
     
    [arr_source2 arr_uncert] = convert_step_data_2_arr(true_data.meas);
   
    
    [r c] = size(arr_source);
    state_size = c-1;
    real_meas_size = state_size;
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
    
	    % display data of element i
	    figures.est_meas_trajectory(i) = subplot(fig_height,fig_width,i);
        
	    plot(arr_source(1:to,1),arr_source(1:to,i+1),'o')
    	xlabel 'step';
    	ylabel 'value';
    	title (['estimated and true meas trajectory element ',num2str(i)]);
	 
        hold on;
        plot(arr_source2(1:to,1),arr_source2(1:to,i+1),'x');
        hold off;	
    end
    
    
    
    % prior state trajectories
    figures.est_prior_state_trajectories = figure;
            
    [post_val prior_uncert] = convert_step_data_2_arr(kf_data.x_post);
    arr_source = post_val;
    
    [arr_source2 arr_uncert] = convert_step_data_2_arr(true_data.meas);
    
    arr_source = arr_source2 - arr_source;
        
    [r c] = size(arr_source);
    state_size = c-1;
    real_state_size = state_size; %for later use in uncertainties..
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
    
	    % display data of element i
	    figures.est_prior_state_trajectory(i) = subplot(fig_height,fig_width,i);
        
	    plot(arr_source2(1:to,1),arr_source(1:to,i+1));
    	xlabel 'step';
    	ylabel 'value';
     	title (['diff true and estimated meas trajectory element ',num2str(i)]);

    end
    
    
    