function [figures] = charts_combi_multi_lm(data, kf_data, conv_meas, first, num, dot_meas)
% also plots markers at measurement steps when there is a measurement

	% display charts for different variables
	if nargin < 3,
        disp 'plots mixed true_data-kf_data plots';
        disp 'syntax: figures = charts_combi_multi_lm(true_data, kf_data, convert_measurements, nr_of_steps_to_show, show_numbers, make_measurement_dots)';
        disp 'num = 0: no numbers; num = 1: numbers everywhere; num = 2: only when measurements.';
        error('not enough parameters');
    elseif nargin == 3,
        first = 0;
        num = 0;
        dot_meas = 0;
       
    end;
    
    %figure;
    
    % source array:
    [arr2 arr_uncert] = convert_step_data_2_arr(kf_data.x_post);
    [arr3 arr3_uncert] = convert_step_data_2_arr(kf_data.x_prior);
    arr1 = data.process;
    [size_process tmp] = size(arr1);
    
    
    [res] = combine_prior_and_post(kf_data);
    
    
    titl = 'true (b) and estimated post (r) and est. prior (m) x,y and meas trajectory';
    
    % variable:
    var1 = 2; name1 = 'x(cm)';
    var2 = 3; name2 = 'y(cm)';
    
    % style
    style1 = 'b:';
    style2 = 'r-';
    style3 = 'm-';
    
    
	% nr of subplots:
    fig_width = 1;
    fig_height = 1;
           
	% display estimated path with true measurements
	figures.traj_fig = figure;
    figures.estim_traj = subplot(1,1,1);
    
    if ~(first==0),
        to = first;
    else
        to = size_process;
    end;
    
    
    plot(arr1(1:to,var1),arr1(1:to,var2),style1);
    hold on;
   % plot(arr3(1:to,var1),arr3(1:to,var2),style3);
    plot(arr2(1:to,var1),arr2(1:to,var2),'r:');
   
    xlabel (name1);
	ylabel (name2);
	title (titl);
	
	
    hold on;
	
   
   
	% add true measurements
    % nb: measurements are relative to the robots position
    % so, we add the estimate position of the robot, to get
    % the total estimated location of where the robot expects
    % the landmark to be..
    [prior_val arr_uncert] = convert_step_data_2_arr(kf_data.x_prior);
    [z_hat_val arr_uncert] = convert_step_data_2_arr(kf_data.z_hat);
   
    [meas_dat arr_uncert] = convert_step_data_2_arr(data.meas);
    [proc_dat] = expand_process(data.process, meas_dat);

 
    if conv_meas == 1,
        test1 = diff_drive_convert_rel_meas_to_abs(proc_dat, meas_dat);
        test2 = diff_drive_convert_rel_meas_to_abs(prior_val, z_hat_val);
    else
        test1 = meas_dat;
        test2 = z_hat_val;
    end;
    
    plot(test1(1:to,2),test1(1:to,3),'bx');
    plot(test2(1:to,2),test2(1:to,3),'ro');
     
    
    for k = 1:to-1, 
        tmp_data(1,1) = res(k).value.from(1,var1);
        tmp_data(1,2) = res(k).value.from(1,var2);
        tmp_data(2,1) = res(k).value.to(1,var1);
        tmp_data(2,2) = res(k).value.to(1,var2);
        
        
        % if there was a measurement, then there was a correction
        % otherwise it was copying the prior
        if (isnan(meas_dat(k,2))),
            plot(tmp_data(:,1), tmp_data(:,2),'b-');    % copying
        else
            plot(tmp_data(:,1), tmp_data(:,2),'r-');    % correction
            
       
             
        end;
        
        tmp_data(1,1) = tmp_data(2,1);
        tmp_data(1,2) = tmp_data(2,2);
        tmp_data(2,1) = res(k+1).value.from(1,var1);
        tmp_data(2,2) = res(k+1).value.from(1,var2);
        
        plot(tmp_data(:,1), tmp_data(:,2),'b-');
        
    end;
    
    if num>0,
       
       set(0,'DefaulttextFontSize',8);
              
       for klm = 1:to,
            str = ['\leftarrow' num2str(klm)];
            
            if num == 1,
                text(arr1(klm,var1),arr1(klm,var2),str);
                text(arr3(klm,var1),arr3(klm,var2),str);
                text(arr2(klm,var1),arr2(klm,var2),str);
                text(test1(klm,2),test1(klm,3),str);
                text(test2(klm,2),test2(klm,3),str);
            elseif num == 2,
                if ~isnan(meas_dat(klm,2)),
                    
                    if dot_meas==1,
                        text(arr1(klm,var1),arr1(klm,var2),['\bullet' str]);
                    else
                        text(arr1(klm,var1),arr1(klm,var2),str);
                    end;
                    
                    text(arr3(klm,var1),arr3(klm,var2),str);
                    text(arr2(klm,var1),arr2(klm,var2),str);
                    text(test1(klm,2),test1(klm,3),str);
                    text(test2(klm,2),test2(klm,3),str);

                end;
            end;
       end;
    end;
  
    	
    
    
    
       % combine prior and posterior data
       
       
    [res] = combine_prior_and_post_error(data,kf_data);
    [z_hat_val z_hat_uncert] = convert_step_data_2_arr(kf_data.z_hat);
   
         
   
    % mixed prior and posterior state trajectories
    figures.est_prior_state_trajectories = figure;
            
    %[prior_val prior_uncert] = convert_step_data_2_arr(kf_data.x_prior);
    %arr_source = prior_val;
    
   
    [r c] = size(res(1).value.from);
    state_size = c-1;
    real_state_size = state_size; %for later use in uncertainties..
    
    fig_width = 1;
    fig_height = state_size;
    
    
    for i=1:state_size
    
         var1 = 1;
         var2 = i+1;
   
        % display data of element i
	    figures.est_prior_state_trajectory(i) = subplot(fig_height,fig_width,i);
        hold on;
        
        for k = 1:to-1, 
            tmp_data(1,1) = res(k).value.from(1,var1);
            tmp_data(1,2) = res(k).value.from(1,var2);
            tmp_data(2,1) = res(k).value.to(1,var1);
            tmp_data(2,2) = res(k).value.to(1,var2);
        
        
            % if there was a measurement, then there was a correction
            % otherwise it was copying the prior
            if (isnan(z_hat_val(k,2))),
                plot(tmp_data(:,1), tmp_data(:,2),'b:');    % copying
            else
                plot(tmp_data(:,1), tmp_data(:,2),'r:');    % correction
            end;
        
            tmp_data(1,1) = tmp_data(2,1);
            tmp_data(1,2) = tmp_data(2,2);
            tmp_data(2,1) = res(k+1).value.from(1,var1);
            tmp_data(2,2) = res(k+1).value.from(1,var2);
        
            plot(tmp_data(:,1), tmp_data(:,2),'b:');
            
            
        
        end;
       
        
	    var1 = 1;
        var2 = i+1+(i-1)*3;
   
        % display data of element i
	    hold on;
        
        for k = 1:to-1, 
            tmp_data(1,1) = res(k).uncert.from(1,var1);
            tmp_data(1,2) = 2*sqrt(res(k).uncert.from(1,var2));
            tmp_data(2,1) = res(k).uncert.to(1,var1);
            tmp_data(2,2) = 2*sqrt(res(k).uncert.to(1,var2));
        
        
            % if there was a measurement, then there was a correction
            % otherwise it was copying the prior
            if (isnan(z_hat_val(k,2))),
                plot(tmp_data(:,1), tmp_data(:,2),'b-');    % copying
            else
                plot(tmp_data(:,1), tmp_data(:,2),'r-');    % correction
            end;
        
            tmp_data(1,1) = tmp_data(2,1);
            tmp_data(1,2) = tmp_data(2,2);
            tmp_data(2,1) = res(k+1).uncert.from(1,var1);
            tmp_data(2,2) = 2*sqrt(res(k+1).uncert.from(1,var2));
        
            plot(tmp_data(:,1), tmp_data(:,2),'b-');
            
            tmp_data(1,1) = res(k).uncert.from(1,var1);
            tmp_data(1,2) = -2*sqrt(res(k).uncert.from(1,var2));
            tmp_data(2,1) = res(k).uncert.to(1,var1);
            tmp_data(2,2) = -2*sqrt(res(k).uncert.to(1,var2));
        
        
            % if there was a measurement, then there was a correction
            % otherwise it was copying the prior
            if (isnan(z_hat_val(k,2))),
                plot(tmp_data(:,1), tmp_data(:,2),'b-');    % copying
            else
                plot(tmp_data(:,1), tmp_data(:,2),'r-');    % correction
            end;
        
            tmp_data(1,1) = tmp_data(2,1);
            tmp_data(1,2) = tmp_data(2,2);
            tmp_data(2,1) = res(k+1).uncert.from(1,var1);
            tmp_data(2,2) = -2*sqrt(res(k+1).uncert.from(1,var2));
        
            plot(tmp_data(:,1), tmp_data(:,2),'b-');
            
        end;

	   % plot(arr_source(:,1),arr_source(:,i+1))
    	xlabel 'step';
    	ylabel 'value';
    	title (['prediction and correction error plus uncertainties, element ',num2str(i)]);
	
    end
    
    
       
   