function [z_real] = diff_drive_get_real_multiple_lm_meas_from_map(x_real, R_real)
% returns list of measurements z_real

   global world;
    
   
   global one_lm_meas_para;
   
   nr_of_meas = 0;  % reset measurement counter
   
   
   [tmp nr_of_lm] = size(world.lm);
   
    
   % find closest lm
   dist_closest = 1000000000;
   
   for lm_id=1:nr_of_lm,
   
        % calculate the x,y,phi to one landmark, without noise
        lm = world.lm(lm_id).pos;
    
        x = (lm.value(1,1) - x_real.value(1,1))*cos( x_real.value(3,1)) + (lm.value(2,1) - x_real.value(2,1))*sin( x_real.value(3,1));
        y = (x_real.value(1,1) - lm.value(1,1))*sin( x_real.value(3,1)) + (lm.value(2,1) - x_real.value(2,1))*cos( x_real.value(3,1));
        phi = lm.value(3,1) - x_real.value(3,1);

        dist = sqrt(x^2+y^2);
    
        if dist<one_lm_meas_para.max_dist,    % check if visible from sensor
            
            % if visible, measurement found
            nr_of_meas = nr_of_meas + 1;
            
            z_real(nr_of_meas).value = [x;y;phi];
            z_real(nr_of_meas).id = world.lm(lm_id).id;
            z_real(nr_of_meas).type = world.lm(lm_id).type;
   
            % add sensor specific noise, independent of distance
            [m n] = size(R_real.uncert);
            for i=1:m, z_real(nr_of_meas).value(i,1) = z_real(nr_of_meas).value(i,1) + sqrt(R_real.uncert(i,i))*randn; end;
         
            % copy uncertainty. uncertainty is simply measurement uncertainty
            % uncertainty on map does not have to do with uncertainty in
            % measurement
            for i=1:m, for j=1:m, z_real(nr_of_meas).uncert(i,j) = R_real.uncert(i,j); end; end;
               
        end;
    end;
    
    if nr_of_meas == 0,    % if no measurements, make dummy with NaNs
        
       z_real(1).value(1,1) = NaN;
       z_real(1).value(2,1) = NaN;
       z_real(1).value(3,1) = NaN;
        
       [m n] = size(R_real.uncert);
        
        % copy uncertainty
        for i=1:m, for j=1:m, z_real(1).uncert(i,j) = NaN; end; end;

    end;
    
   % disp 'real measurement made.';

