
function [problem, x_prior, x_post,  K, z_hat, z_res] = make_ekfx_step(problem)

    % given a problem model, estimates the state using 
    % the Linear Kalman Filter equations

    % start ekf with time update
    pr 'perform ekf time update';

    % time update step has to include the time info in every prior belief
    % notice that we can do this by only computing the displacement once..
    % notice that we use standard ekf time update step..
    
    % state_belief is a collection of gaussians
    [r c] = size(problem.model.state_belief);
    for i=1:c,
    
       problem.model.state_est.value = problem.model.state_belief(i).value;
       problem.model.state_est.uncert = problem.model.state_belief(i).uncert;
    
       [a.value a.uncert] = ekf_time_update_step(problem);  % same as before
    
       problem.model.state_belief(i).value = a.value;        % update prior state belief
       problem.model.state_belief(i).uncert = a.uncert;
    
       x_prior(1).value = problem.model.state_belief(i).value;
       x_prior(1).uncert = problem.model.state_belief(i).uncert;
       
    end;
    
    add_to_plot_multi(problem.model.state_belief,'ro');
                
    
    % execute time update
    %[x_prior(1).value c_x_prior(1).uncert] = ekf_time_update_step(problem);
    %[x_prior(1).value x_prior(1).uncert] = ekf_time_update_step(problem);

    % and save the result
    %problem.model.state_est.value = x_prior(1).value;
    %problem.model.state_est.uncert = x_prior(1).uncert;

    % and result to ui
    display_info(problem);


    
    
    % next, perform the measurement update
    pr 'perform ekf measurement update';

    
    % check if there is a measurement
    zs = problem.env.meas.result.data;
    
    [tmp nr_of_measurements] = size(zs);
    
    no_meas = 0;
    
    if nr_of_measurements==1, % then either there is real or dummy
        
        if isnan( zs(1).value(1,1) ), % if first element is NaN, then dummy
            no_meas = 1;
        else
            no_meas = 0; % otherwise it is a real measurement
        end;
        
    end;
        

    %if no real measurement, then copy prior info to posterior and return
    if no_meas,
        
        x_post(1).value = x_prior(1).value;
        x_post(1).uncert = x_prior(1).uncert;
        
        % make K with NaNs..
        [r c] = size(zs(1).value);
        [r2 c2] = size(x_post(1).value);
        for a=1:r,
            
            z_hat(1).value(a,1) = NaN;   % create also z_hat with NaN..
            z_res(1).value(a,1) = NaN;   % and z_res..
            
            for c=1:r,
                z_res(1).uncert(r,c) = NaN; % and fill C_res with NaNs..
                z_hat(1).uncert(r,c) = NaN;
            end
            
            for b=1:r2,
                K(1).value(b,a) = NaN;
                K(1).uncert(b,a) = NaN; % filling...
            end
        end
        
        
        
    else  % walk through different measurements
        
       
%        for kk=1:nr_of_measurements, % deal with multiple different measurements
            kk=1; % assume at most one measurement
            
            z_tr.value = zs(kk).value;
            z_tr.uncert = zs(kk).uncert;
            
            problem.model.meas.curr_meas = zs(kk);  % save meas, such that parameters can be formed (ie landmark detection)
            
            % save prior state and uncert
            % if there is one measurement, then we already did this,
            % if there are more, we save one prior for every measurement
%            if (kk>1), % prior k=1 is already filled in above
                
%                x_prior(kk).value = x_post(kk-1).value;
%                x_prior(kk).uncert = x_post(kk-1).uncert;
                
%            end;


            % we now have to get a list of the potential landmarks L1 ...
            % Li and use these landmarks to make predictions
            [objects] = get_corresponding_objects(problem);
            
            [pp qq] = size(objects.lm_id);
            
            problem.model.state_belief_post = [];
            
            index = 0;
            if pp>0, % if there are corresponding objects..
            
                     
                global uniform;
                if uniform, % first measurement
                    first_meas = 1;
                    uniform = 0;
                else
                    first_meas = 0;
                end;
                        
                for ii=1:pp, % walk through all corresponding objects..

                    problem.model.meas.curr_id = objects.lm_id(ii);
                    
                    % for every prior state, make posterior state including
                    % any of the objects
         
                    [r c] = size(problem.model.state_belief); % prior states
                    for i=1:c,
                
                        problem.model.state_est.value = problem.model.state_belief(i).value;
                        problem.model.state_est.uncert = problem.model.state_belief(i).uncert;

                        % execute measurement update
                        [x_post(kk).value x_post(kk).uncert K(kk).value z_hat(kk).value z_hat(kk).uncert z_res(kk).value z_res(kk).uncert z(kk).value] = ekf_meas_update_step(problem, z_tr);

                        % and save the result
                       % problem.model.state_est.value = x_post(kk).value;
                       % problem.model.state_est.uncert = x_post(kk).uncert;
                       
                        % save new posterior, only if uncertainty is small
                        % enough!
                        
                        
                       % if(c < 20 || small_enough_covar(x_post, problem.model.belief_thres)),
                            obs_prob = draw_gauss_3d_make(z_hat(kk).value, z_hat(kk).uncert, z(kk).value, 3);
                            
                            if ~isfield(problem.model.state_belief(i),'prob'),
                                problem.model.state_belief(i).prob = 1;
                            end;
                            
                            if first_meas,  % if first meas, no prior measurements
                                prob = objects.lm_prob(ii);
                            else
                               
                                prob = objects.lm_prob(ii)*problem.model.state_belief(i).prob*obs_prob;
                            end;

                            if prob>0,
                                index = index+1;
                                problem.model.state_belief_post(index).prob = prob;
                                problem.model.state_belief_post(index).value = x_post(kk).value;
                                problem.model.state_belief_post(index).uncert = x_post(kk).uncert;
                            end;           
                            % probability of observing lm lm_id:
                            % z_hat contains prediction given lm_id with
                            % uncert
                            % given old location problem.model.state_belief(i)
                                        
                        K(kk).uncert = K(kk).value; %filling for compatibility..
                        
                    end;
                    
                end;
                
                if ~isfield(problem.model, 'state_belief_post') 
                    %disp 'all posteriors filtered away';
                  
                else
                    
                    % set belief to newly calculated belief
                    problem.model.state_belief = problem.model.state_belief_post;
                end;
            
                add_to_plot_multi(problem.model.state_belief_post,'bp');
                
            else
                
                % if no typ x landmarks found..
                % copy prior to posterior
                
                x_post(1).value = x_prior(1).value;
                x_post(1).uncert = x_prior(1).uncert;
                
                % make K with NaNs..
                [r c] = size(zs(1).value);
                [r2 c2] = size(x_post(1).value);
                for a=1:r,
                    
                    z_hat(1).value(a,1) = NaN;   % create also z_hat with NaN..
                    z_res(1).value(a,1) = NaN;   % and z_res..
                    
                    for c=1:r,
                        z_res(1).uncert(r,c) = NaN; % and fill C_res with NaNs..
                        z_hat(1).uncert(r,c) = NaN;
                    end
                    
                    for b=1:r2,
                        K(1).value(b,a) = NaN;
                        K(1).uncert(b,a) = NaN; % filling...
                    end
                end
            end;
            
      %    end;
        
        problem.model.meas.curr_meas = [];
        
    end
    
    
    
   
    % and result to ui
    display_info(problem);
    
    % ekf is done
    pr 'ekf step performed.';
