
function [prob, ctrl, x, z, x_prior, x_post, K, z_hat, z_res] = run_one_cycle(prob, kf_method, method)
% performs one cycle of process execution and KF
% 'method' indicates what the run has to do:
%
%   method = 1: online run process and run KF
%   method = 2: run only process, no KF
%   method = 3: no process, only KF
%   method = 4: only run process make measurement
%
%   in method 2, the control, state and measurements should be saved by
%   calling function
%   in method 3, calling function should set control, state and measurement
%   prior to calling this function
%   

    % if not only KF, then parameters for process have to be made..
    if (method==1 || method==2 )
        
        
        % create possible control input
        pr 'make control decision';
    
        % get parameter values in paras, which starts with a ','
        [para paras n] = paras2string(prob, prob.env.control);
  
        % create command to get decision
        cmd = strcat('prob.env.control.result = feval(prob.env.control.function', paras,');');
    
        % and make the decision, which will be stored in result.value..
        eval(cmd);
    
        ctrl = prob.env.control.result;
        
        % print decision
        pr 'decision is:';
        pr (prob.env.control.result.value);
    
        
        
        % perform the action
        pr 'performing process step';
    
        % get parameter values in paras
        [para paras n] = paras2string(prob, prob.env.process);
  
        % create command to perform process step
        cmd = strcat('prob.env.process.result = feval(prob.env.process.function', paras,');');
    
        % and make the process step
        eval(cmd);
    
        % copy the result of the process function to the new state
        prob.env.state.value = prob.env.process.result.value;
        prob.env.state.uncert = prob.env.process.result.uncert;
        
        % result is stored in 'result.value'
        x = prob.env.process.result;
        
        % print result
        pr 'resulting true state:';
        pr (prob.env.process.result.value);
    
    
    
        % make a measurement
        pr 'making a measurement';
    
     
        % get parameter values in paras
        [para paras n] = paras2string(prob, prob.env.meas);
  
        % create command to get measurement
        cmd = strcat('prob.env.meas.result = feval(prob.env.meas.function', paras,');');
    
        % and make the measurement
        eval(cmd);
    
        z = prob.env.meas.result;
        
%        pr 'resulting measurement:';
%        pr (prob.env.meas.result.value);
    
        display_info(prob);
        
    else
        if( method == 4) % only make measurement
            
            % get parameter values in paras
            [para paras n] = paras2string(prob, prob.env.meas);
      
            % create command to get measurement
            cmd = strcat('prob.env.meas.result = feval(prob.env.meas.function', paras,');');
    
            % and make the measurement
            eval(cmd);
    
            z = prob.env.meas.result;
        
    %        pr 'resulting measurement:';
    %        pr (prob.env.meas.result.value);
            
            ctrl = [];
            x = [];
            
        else
        
            % if no true things should be done..
            ctrl = [];
            x = [];
            z = [];
            
            
        end;
    end;
    
    % if a KF step has to be performed..
    if (method==1 || method==3)
        % KF
        % make an kf step
        [prob x_prior x_post K z_hat z_res] = feval(kf_method.make_step,prob);
 
        % display state info
        display_info(prob);
        
    else
        
        % if no KF step should be performed..
        x_prior(1).value = [];
        x_prior(1).uncert = [];
        
        x_post(1).value = [];
        x_post(1).uncert = [];
        
        K(1).value = [];
        K(1).uncert = [];
        
        z_hat.value = [];
        z_hat(1).uncert = [];
        
        z_res(1).value = [];
        z_res(1).uncert = [];

    end;
    
    
    
    