function [x_post, C_x_post, K, z_hat, C_z_hat, z_res, C_res] = ekf_meas_update_step(prob)

    % extract parameters and Jacobians etc from model
    [h n para J] = get_model_settings(prob, prob.model.meas);
   
    % assuming the first argument is the old state (!)
    C_x_prior = para(1).uncert;
    x_prior = para(1).value;
 
    
    % get last made real measurement 
    [z] = prob.env.meas.result.value;
    
    %if no real measurement, then 
    if isnan(z(1,1))
        x_post = x_prior;
        C_x_post = C_x_prior;
        
        % make K with NaNs..
        [r c] = size(z);
        [r2 c2] = size(x_post);
        for a=1:r,
            
            z_hat(a,1) = NaN;   % create also z_hat with NaN..
            z_res(a,1) = NaN;   % and z_res..
            
            for c=1:r,
                C_res(r,c) = NaN; % and fill C_res with NaNs..
                C_z_hat(r,c) = NaN;
            end
            
            for b=1:r2,
                K(b,a) = NaN;
            end
        end
        
        return
    end
    
    
        
    % make measurement prediction
    [z_hat] = feval(h, para(:).value);
    
    
    % calculate measurement residual
    [z_res] = z - z_hat;
    
    
    % calculate uncertainty in redidual
    % this is noise in prediction plus measurement
    for i=1:n,
        C_tmp(i).influence = J(i).m*para(i).uncert*(J(i).m');
    end;
        
    C_res = C_tmp(1).influence;
    if n>1, for i=2:n, C_res = C_res + C_tmp(i).influence; end; end;
    

    % the uncertainty in the prediction is the uncertainty in residual..
    C_z_hat = C_res;
    
    % ready for updates...
     
    % calculate Kalman gain   
    K = (C_x_prior*((J(1).m)'))*( inv(C_res) );
    
    
    % update state
    x_post = x_prior + K*z_res;
    
    % and uncertainty
    C_x_post = C_x_prior - K*(J(1).m)*C_x_prior;

    % done.
    pr 'ekf measurement update performed.';

